Coverage for api/enhance.py: 0%

# Coverage for api/enhance.py : 0%

## 7 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 import json

2 import os

3

4 from flask import current_app

5 from flask import url_for

6

7

8 def base_context():

9 """

10 Used to define global template values

11

12

13 Returns

14 -------

15 dict

16 copy of dictionary

17 """

18

19 base_context = {}

20 return base_context.copy()